Mobile phone numbers or landline numbers are represented as integer vectors. International
calling prefixes extend the number beyond the representation of signed
integers. We use raw vectors for the international prefix, if required.
If ignore_calling_code = TRUE, the integer vector is returned.
Elements of x for which the mobile phone number could not be
extracted map to NA_integer_ in the result.
If ignore_calling_code = FALSE, then a list is returned. The second element
of the list is the calling prefix.
If ignore_calling_code = NA then it is set to TRUE if x
appears to have international prefixes already.
dauphin_mobile
An integer vector, the integer representation of
the mobile phone. If the calling code is required or requested, a list
of two vectors is returned, with the second element a raw vector with
a representation of the corresponding number.
dauphin_landline
An integer vector, the integer representation of the landline.
dauphin_mobile_landline
A list of two vectors with the
mobile and landline vectors respectively, even if the character
vectors passed are in the wrong order (or partially in the wrong order).
Useful if some of the entries
are in the wrong place.